@@ -1,4 +1,3 @@
-from argparse import ArgumentParser, RawTextHelpFormatter
 import os
 from pathlib import Path
 import subprocess
@@ -17,11 +16,11 @@ class FfmpegProcess:
         self._command = command
         index_of_filepath = self._command.index("-i") + 1
         self._filepath = self._command[index_of_filepath]
-    
+
         self._can_get_duration = True
 
         try:
-            duration_secs = float(probe(self._filepath)["format"]["duration"])
+            self._duration_secs = float(probe(self._filepath)["format"]["duration"])
         except Exception:
             self._can_get_duration = False
 
@@ -29,7 +28,7 @@ class FfmpegProcess:
 
         if self._can_get_duration:
             # pipe:1 sends the progress to stdout. See https://stackoverflow.com/a/54386052/13231825
-            self._ffmpeg_args += ["-progress", "pipe:1", "-nostats"] 
+            self._ffmpeg_args += ["-progress", "pipe:1", "-nostats"]
 
     def run(self, progress_handler=None, ffmpeg_output_file=None):
         """
@@ -52,36 +51,40 @@ class FfmpegProcess:
         popen_args = [self._ffmpeg_args]
 
         if self._can_get_duration:
-            print('IN DURATION')
-    
+
             with open(ffmpeg_output_file, "a") as f:
                 self._process = subprocess.Popen(
-                    self._ffmpeg_args,
-                    stdout=subprocess.PIPE,
-                    stderr=f
+                    self._ffmpeg_args, stdout=subprocess.PIPE, stderr=f
                 )
 
-            progress_bar = tqdm(
-                total=duration_secs,
-                unit="s",
-                dynamic_ncols=True
-            )
+            progress_bar = tqdm(total=self._duration_secs, unit="s", dynamic_ncols=True)
             progress_bar.clear()
             previous_seconds_processed = 0
         else:
-            print('ELSE')
             self._process = subprocess.Popen(self._ffmpeg_args)
 
         try:
             while self._process.poll() is None:
                 if self._can_get_duration:
                     line = self._process.stdout.readline().decode("utf-8")
-                    # Format: out_time_ms=3505000
                     if "out_time_ms" in line:
                         seconds_processed = int(line.strip()[12:]) / 1_000_000
+
+                    # A progress handler was not specified. Use tqdm to show a progress bar.
+                    if progress_handler is None:
                         seconds_increase = seconds_processed - previous_seconds_processed
                         progress_bar.update(seconds_increase)
                         previous_seconds_processed = seconds_processed
+                    # A progress handler was specified.
+                    else:
+                        percentage = round((seconds_processed / self._duration_secs) * 100, 1)
+                        if "speed" in ffmpeg_output:
+                            speed = ffmpeg_output.split("=")[1].strip()
+                            speed = 0 if " " in speed or "N/A" in speed else float(speed[:-1])
+                            if speed != 0:
+                                eta = (file_duration - secs) / speed
+                                progress_handler(percentage, f"{speed}x", eta)
+
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
